pub struct PulseOutputSourceUpdater<'a> { /* private fields */ }Available on Linux only.
Used to update the source this updater was created from. For more details look at docs for the corresponding builder.
Implementations
Sourceimpl<'a> PulseOutputSourceUpdater<'a>
impl<'a> PulseOutputSourceUpdater<'a>
Sourcepub fn set_device_id<T: Into<ObsString> + Sync + Send>(
self,
device_id: T,
) -> Self
pub fn set_device_id<T: Into<ObsString> + Sync + Send>( self, device_id: T, ) -> Self
PulseAudio device name/ID
Sourceimpl<'a> PulseOutputSourceUpdater<'a>
impl<'a> PulseOutputSourceUpdater<'a>
Sourcepub fn set_default_device(self) -> Self
pub fn set_default_device(self) -> Self
Set the default PulseAudio output device