V4L2InputSourceUpdater

Struct V4L2InputSourceUpdater 

pub struct V4L2InputSourceUpdater<'a> { /* private fields */ }
Available on Linux only.
Used to update the source this updater was created from. For more details look at docs for the corresponding builder.

Implementations

Source

impl<'a> V4L2InputSourceUpdater<'a>

pub fn set_device_id<T: Into<ObsString> + Sync + Send>( self, device_id: T, ) -> Self

Device ID/path (e.g., “/dev/video0”)

pub fn set_input(self, input: i64) -> Self

Input number on the device

pub fn set_pixelformat(self, pixelformat: i64) -> Self

Pixel format (FOURCC code as integer)

pub fn set_standard(self, standard: i64) -> Self

Video standard for analog inputs

pub fn set_dv_timing(self, dv_timing: i64) -> Self

DV timing for digital inputs

pub fn set_resolution(self, resolution: i64) -> Self

pub fn set_framerate(self, framerate: i64) -> Self

pub fn set_color_range(self, color_range: i64) -> Self

Color range setting

pub fn set_auto_reset(self, auto_reset: bool) -> Self

Auto-reset on timeout

pub fn set_timeout_frames(self, timeout_frames: i64) -> Self

Frames until timeout