X11CaptureSourceBuilder

Struct X11CaptureSourceBuilder 

pub struct X11CaptureSourceBuilder { /* private fields */ }
Available on Linux only.
A source to capture X11 screen/window content.

This source provides screen capture functionality on Linux systems running X11. It can capture the entire screen or specific areas with cropping options.

Implementations

Source

impl X11CaptureSourceBuilder

pub fn set_screen(self, screen: i64) -> Self

Screen/Display to capture

pub fn set_show_cursor(self, show_cursor: bool) -> Self

Whether to show the cursor in the capture

pub fn set_advanced(self, advanced: bool) -> Self

Enable advanced settings

pub fn set_server<T: Into<ObsString> + Sync + Send>(self, server: T) -> Self

X Server to connect to (when using advanced settings)

pub fn set_cut_top(self, cut_top: i64) -> Self

Crop from top (in pixels)

pub fn set_cut_left(self, cut_left: i64) -> Self

Crop from left (in pixels)

pub fn set_cut_right(self, cut_right: i64) -> Self

Crop from right (in pixels)

pub fn set_cut_bot(self, cut_bot: i64) -> Self

Crop from bottom (in pixels)