XCompositeInputSourceBuilder

Struct XCompositeInputSourceBuilder 

pub struct XCompositeInputSourceBuilder { /* private fields */ }
Available on Linux only.
A source to capture X11 windows using XComposite.

This source provides window capture functionality on Linux systems running X11 using the XComposite extension. It can capture individual windows with their transparency and effects intact.

Implementations

Source

impl XCompositeInputSourceBuilder

pub fn set_capture_window<T: Into<ObsString> + Sync + Send>( self, capture_window: T, ) -> Self

Window to capture (window ID as string)

pub fn set_cut_top(self, cut_top: i64) -> Self

Crop from top (in pixels)

pub fn set_cut_left(self, cut_left: i64) -> Self

Crop from left (in pixels)

pub fn set_cut_right(self, cut_right: i64) -> Self

Crop from right (in pixels)

pub fn set_cut_bot(self, cut_bot: i64) -> Self

Crop from bottom (in pixels)

pub fn set_show_cursor(self, show_cursor: bool) -> Self

Whether to show the cursor in the capture

pub fn set_include_border(self, include_border: bool) -> Self

Include window border/decorations

pub fn set_exclude_alpha(self, exclude_alpha: bool) -> Self

Exclude alpha channel (disable transparency)