XCompositeInputSourceUpdater

Struct XCompositeInputSourceUpdater 

pub struct XCompositeInputSourceUpdater<'a> { /* private fields */ }
Available on Linux only.
Used to update the source this updater was created from. For more details look at docs for the corresponding builder.

Implementations

Source

impl<'a> XCompositeInputSourceUpdater<'a>

pub fn set_capture_window<T: Into<ObsString> + Sync + Send>( self, capture_window: T, ) -> Self

Window to capture (window ID as string)

pub fn set_cut_top(self, cut_top: i64) -> Self

Crop from top (in pixels)

pub fn set_cut_left(self, cut_left: i64) -> Self

Crop from left (in pixels)

pub fn set_cut_right(self, cut_right: i64) -> Self

Crop from right (in pixels)

pub fn set_cut_bot(self, cut_bot: i64) -> Self

Crop from bottom (in pixels)

pub fn set_show_cursor(self, show_cursor: bool) -> Self

Whether to show the cursor in the capture

pub fn set_include_border(self, include_border: bool) -> Self

Include window border/decorations

pub fn set_exclude_alpha(self, exclude_alpha: bool) -> Self

Exclude alpha channel (disable transparency)