pub struct X11CaptureSourceBuilder { /* private fields */ }Available on Linux only.
A source to capture X11 screen/window content.
This source provides screen capture functionality on Linux systems running X11. It can capture the entire screen or specific areas with cropping options.
Implementations
Sourceimpl X11CaptureSourceBuilder
impl X11CaptureSourceBuilder
Sourcepub fn set_screen(self, screen: i64) -> Self
pub fn set_screen(self, screen: i64) -> Self
Screen/Display to capture
Sourcepub fn set_show_cursor(self, show_cursor: bool) -> Self
pub fn set_show_cursor(self, show_cursor: bool) -> Self
Whether to show the cursor in the capture
Sourcepub fn set_advanced(self, advanced: bool) -> Self
pub fn set_advanced(self, advanced: bool) -> Self
Enable advanced settings
Sourcepub fn set_server<T: Into<ObsString> + Sync + Send>(self, server: T) -> Self
pub fn set_server<T: Into<ObsString> + Sync + Send>(self, server: T) -> Self
X Server to connect to (when using advanced settings)
Sourcepub fn set_cut_top(self, cut_top: i64) -> Self
pub fn set_cut_top(self, cut_top: i64) -> Self
Crop from top (in pixels)
Sourcepub fn set_cut_left(self, cut_left: i64) -> Self
pub fn set_cut_left(self, cut_left: i64) -> Self
Crop from left (in pixels)
Sourcepub fn set_cut_right(self, cut_right: i64) -> Self
pub fn set_cut_right(self, cut_right: i64) -> Self
Crop from right (in pixels)
Sourcepub fn set_cut_bot(self, cut_bot: i64) -> Self
pub fn set_cut_bot(self, cut_bot: i64) -> Self
Crop from bottom (in pixels)